pub enum GetDifferencesError {
Show 16 variants
CommitDoesNotExist(String),
CommitRequired(String),
EncryptionIntegrityChecksFailed(String),
EncryptionKeyAccessDenied(String),
EncryptionKeyDisabled(String),
EncryptionKeyNotFound(String),
EncryptionKeyUnavailable(String),
InvalidCommit(String),
InvalidCommitId(String),
InvalidContinuationToken(String),
InvalidMaxResults(String),
InvalidPath(String),
InvalidRepositoryName(String),
PathDoesNotExist(String),
RepositoryDoesNotExist(String),
RepositoryNameRequired(String),
}Expand description
Errors returned by GetDifferences
Variants
CommitDoesNotExist(String)
The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
CommitRequired(String)
A commit was not specified.
EncryptionIntegrityChecksFailed(String)
An encryption integrity check failed.
EncryptionKeyAccessDenied(String)
An encryption key could not be accessed.
EncryptionKeyDisabled(String)
The encryption key is disabled.
EncryptionKeyNotFound(String)
No encryption key was found.
The encryption key is not available.
InvalidCommit(String)
The specified commit is not valid.
InvalidCommitId(String)
The specified commit ID is not valid.
InvalidContinuationToken(String)
The specified continuation token is not valid.
InvalidMaxResults(String)
The specified number of maximum results is not valid.
InvalidPath(String)
The specified path is not valid.
InvalidRepositoryName(String)
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
PathDoesNotExist(String)
The specified path does not exist.
RepositoryDoesNotExist(String)
The specified repository does not exist.
RepositoryNameRequired(String)
A repository name is required, but was not specified.
Implementations
Sourceimpl GetDifferencesError
impl GetDifferencesError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<GetDifferencesError>