pub enum GetFileError {
Show 14 variants
CommitDoesNotExist(String),
EncryptionIntegrityChecksFailed(String),
EncryptionKeyAccessDenied(String),
EncryptionKeyDisabled(String),
EncryptionKeyNotFound(String),
EncryptionKeyUnavailable(String),
FileDoesNotExist(String),
FileTooLarge(String),
InvalidCommit(String),
InvalidPath(String),
InvalidRepositoryName(String),
PathRequired(String),
RepositoryDoesNotExist(String),
RepositoryNameRequired(String),
}Expand description
Errors returned by GetFile
Variants
CommitDoesNotExist(String)
The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
EncryptionIntegrityChecksFailed(String)
An encryption integrity check failed.
EncryptionKeyAccessDenied(String)
An encryption key could not be accessed.
EncryptionKeyDisabled(String)
The encryption key is disabled.
EncryptionKeyNotFound(String)
No encryption key was found.
The encryption key is not available.
FileDoesNotExist(String)
The specified file does not exist. Verify that you have used the correct file name, full path, and extension.
FileTooLarge(String)
The specified file exceeds the file size limit for AWS CodeCommit. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
InvalidCommit(String)
The specified commit is not valid.
InvalidPath(String)
The specified path is not valid.
InvalidRepositoryName(String)
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
PathRequired(String)
The folderPath for a location cannot be null.
RepositoryDoesNotExist(String)
The specified repository does not exist.
RepositoryNameRequired(String)
A repository name is required, but was not specified.
Implementations
Sourceimpl GetFileError
impl GetFileError
pub fn from_response(res: BufferedHttpResponse) -> RusotoError<GetFileError>