pub enum UntagResourceError {
InvalidRepositoryName(String),
InvalidResourceArn(String),
InvalidSystemTagUsage(String),
InvalidTagKeysList(String),
RepositoryDoesNotExist(String),
ResourceArnRequired(String),
TagKeysListRequired(String),
TagPolicy(String),
TooManyTags(String),
}Expand description
Errors returned by UntagResource
Variants
InvalidRepositoryName(String)
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
InvalidResourceArn(String)
The value for the resource ARN is not valid. For more information about resources in AWS CodeCommit, see CodeCommit Resources and Operations in the AWS CodeCommit User Guide.
InvalidSystemTagUsage(String)
The specified tag is not valid. Key names cannot be prefixed with aws:.
InvalidTagKeysList(String)
The list of tags is not valid.
RepositoryDoesNotExist(String)
The specified repository does not exist.
ResourceArnRequired(String)
A valid Amazon Resource Name (ARN) for an AWS CodeCommit resource is required. For a list of valid resources in AWS CodeCommit, see CodeCommit Resources and Operations in the AWS CodeCommit User Guide.
TagKeysListRequired(String)
A list of tag keys is required. The list cannot be empty or null.
TagPolicy(String)
The tag policy is not valid.
TooManyTags(String)
The maximum number of tags for an AWS CodeCommit resource has been exceeded.
Implementations
Sourceimpl UntagResourceError
impl UntagResourceError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<UntagResourceError>