pub struct Target {
pub destination_reference: Option<String>,
pub repository_name: String,
pub source_reference: String,
}Expand description
Returns information about a target for a pull request.
Fields
destination_reference: Option<String>The branch of the repository where the pull request changes are merged. Also known as the destination branch.
repository_name: StringThe name of the repository that contains the pull request.
source_reference: StringThe branch of the repository that contains the changes for the pull request. Also known as the source branch.